Index: runtime/vm/simulator_arm64.h |
=================================================================== |
--- runtime/vm/simulator_arm64.h (revision 45418) |
+++ runtime/vm/simulator_arm64.h (working copy) |
@@ -69,7 +69,8 @@ |
int64_t get_last_pc() const; |
void set_pc(int64_t pc); |
- // Accessor to the internal simulator stack top. |
+ // Accessors to the internal simulator stack base and top. |
+ uword StackBase() const { return reinterpret_cast<uword>(stack_); } |
uword StackTop() const; |
// Accessor to the instruction counter. |